/*
 * Copyright (c) 2000-2009 TeamDev Ltd. All rights reserved.
 * TeamDev PROPRIETARY and CONFIDENTIAL.
 * Use is subject to license terms.
 */

package com.teamdev.xpcom.mozilla.demo.components.icon;

import com.teamdev.xpcom.Xpcom;

public class IconBuilder
{
    private static Class<? extends IconLoader> iconLoader = null;

    private IconBuilder()
    {
    }

    /**
     * Root package for all favicon implementation
     */
    private static final String ROOT_PACKAGE = "com.teamdev.xpcom.mozilla.demo.components.icon.";
    /**
     * Windows favicon implementation
     */
    private static final String WINDOWS_ICON = "windows.FavIcon";
    /**
     * Linux favicon implementation
     */
    private static final String LINUX_ICON = "linux.FavIcon";
    /**
     * Mac favicon implementation
     */
    private static final String MAC_ICON = "macos.FavIcon";

    // We shod use unsafe cast
    @SuppressWarnings("unchecked")
    public static IconBuilder createBuilder()
    {
        if (iconLoader == null)
        {
            String factoryClassName = ROOT_PACKAGE;
            if (Xpcom.isWindows())
            {
                factoryClassName += WINDOWS_ICON;
            }
            else if (Xpcom.isLinux())
            {
                factoryClassName += LINUX_ICON;
            }
            else if (Xpcom.isMacOSX())
            {
                factoryClassName += MAC_ICON;
            }

            ClassLoader classLoader = IconBuilder.class.getClassLoader();
            try
            {
                iconLoader = (Class<? extends IconLoader>) Class.forName(
                        factoryClassName, true, classLoader);
            }
            catch (ClassNotFoundException e)
            {
                e.printStackTrace();
                Thread.currentThread().interrupt();
            }
        }
        return new IconBuilder();
    }

    public IconLoader newIconLoader() throws Exception
    {
        return iconLoader.newInstance();
    }
}
