/*
 * Copyright (c) 2000-2009 TeamDev Ltd. All rights reserved.
 * TeamDev PROPRIETARY and CONFIDENTIAL.
 * Use is subject to license terms.
 */
package com.teamdev.xpcom.mozilla.demo.components.icon.macos;

import java.awt.Dimension;
import java.awt.Image;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.net.URL;

import javax.swing.Icon;
import javax.swing.ImageIcon;

import teamdev.jxdesktop.macosx.cocoa.Id;
import teamdev.jxdesktop.macosx.cocoa.nsimage.NSImage;

import com.jniwrapper.util.Logger;
import com.teamdev.xpcom.mozilla.demo.components.icon.IconLoader;
import com.teamdev.xpcom.mozilla.demo.components.icon.JavaImage;

public class FavIcon implements IconLoader
{
    private static final String FAVORITE_ICON_FILE = "/favicon.ico";
    public static final int PREFERRED_SIZE = 16;
    private static final Dimension PREFERRED_DIMENSION = new Dimension(
            PREFERRED_SIZE, PREFERRED_SIZE);
    private static final Logger LOG = Logger.getInstance(FavIcon.class);

    public FavIcon()
    {

    }

    public Icon loadFromURL(final String url)
    {
        BufferedImage bufferedImage = null;
        URL inURL;
        try
        {
            URL iconURL = new URL(url);
            if (iconURL.getHost().equals("") || iconURL.getHost().equals("file"))
            {
                String favIcon = iconURL.getPath().substring(0, iconURL.getPath().lastIndexOf("/")) + FAVORITE_ICON_FILE;
                File icoFile = new File(favIcon);
                if (!icoFile.exists() || !icoFile.isFile())
                {
                    throw new RuntimeException("Can not find file: " + favIcon);
                }

                Id id = new NSImage().initWithContentsOfFile(icoFile.getAbsolutePath());
                NSImage image = new NSImage(id);
                bufferedImage = image.toJavaImage();
            }
            else
            {
                String urlToImage = url + FAVORITE_ICON_FILE;
                if (JavaImage.isJavaSupportImage(urlToImage)) {
                    JavaImage javaImage = new JavaImage(url + FAVORITE_ICON_FILE);
                    bufferedImage = (BufferedImage) javaImage.getImage();
                }
            }
        }
        catch (Exception e)
        {
            LOG.info("Favicon can not load for url: " + url);
            return null;
        }

        assert bufferedImage != null;
        Dimension iconDimesion = new Dimension(bufferedImage.getHeight(), bufferedImage.getWidth());
        Image image = null;
        if (iconDimesion.equals(PREFERRED_DIMENSION)) {
            image = bufferedImage;
        } else {
            image = bufferedImage.getScaledInstance(PREFERRED_SIZE, PREFERRED_SIZE, Image.SCALE_REPLICATE);
        }
        return new ImageIcon(image);
    }
}
