/*
 * Copyright (c) 2000-2009 TeamDev Ltd. All rights reserved.
 * TeamDev PROPRIETARY and CONFIDENTIAL.
 * Use is subject to license terms.
 */
package com.teamdev.xpcom.mozilla.demo.components.icon.windows;

import java.awt.Dimension;
import java.awt.Image;
import java.awt.image.BufferedImage;
import java.io.*;
import java.net.URL;
import java.util.List;

import javax.swing.ImageIcon;

import com.jniwrapper.util.Logger;
import com.jniwrapper.win32.gdi.Icon;
import com.teamdev.xpcom.mozilla.demo.components.icon.JavaImage;
import com.teamdev.xpcom.mozilla.demo.components.icon.IconLoader;

public class FavIcon implements IconLoader
{
    private final Icon icon;
    private static final String FAVORITE_ICON_FILE = "/favicon.ico";
    public static final int PREFERRED_SIZE = 16;
    private static final Dimension PREFERRED_DIMENSION = new Dimension(
            PREFERRED_SIZE, PREFERRED_SIZE);
    private static final Logger LOG = Logger.getInstance(FavIcon.class);

    public FavIcon()
    {
        icon = new Icon();
    }

    public javax.swing.Icon loadFromURL(String url) {
        BufferedImage bufferedImage = null;
        URL inURL;
        try
        {
            inURL = new URL(url);
            if (inURL.getHost().equals("") || inURL.getHost().equals("file"))
            {
                String favIcon = inURL.getPath().substring(0,
                        inURL.getPath().lastIndexOf("/"))
                        + FAVORITE_ICON_FILE;
                icon.load(new File(favIcon), PREFERRED_DIMENSION);
            }
            else
            {
                URL favoriteIconURL = new URL(inURL.getProtocol(), inURL.getHost(), FAVORITE_ICON_FILE);
                // The com.jniwrapper.Icon is Java 1.4 API,
                // we should use List<?> in this case
                List<?> favIconList = Icon.loadFromStream(favoriteIconURL.openStream());
                for (Object icon : favIconList)
                {
                    if (((Icon) icon).getSize().equals(PREFERRED_DIMENSION))
                    {
                        this.icon.load(favoriteIconURL.openStream(), PREFERRED_DIMENSION);
                        break;
                    }
                }
                if (this.icon.isNull() && !favIconList.isEmpty()) {
                    this.icon.load(favoriteIconURL.openStream(), 0);
                }
            }
            bufferedImage = icon.toImage();
        }
        catch (Exception e)
        {
            try {
                String urlToImage = url + FAVORITE_ICON_FILE;
                if (JavaImage.isJavaSupportImage(urlToImage))
                {
                    JavaImage javaImage = new JavaImage(url + FAVORITE_ICON_FILE);
                    bufferedImage = (BufferedImage) javaImage.getImage();
                }
            }
            catch (IOException e1)
            {
                LOG.info("Favicon can not load for url: " + url);
                return null;
            }
        }

        assert bufferedImage != null;
        Dimension iconDimesion = new Dimension(bufferedImage.getHeight(), bufferedImage.getWidth());
        Image image;
        if (iconDimesion.equals(PREFERRED_DIMENSION)) {
            image = bufferedImage;
        } else {
            image = bufferedImage.getScaledInstance(PREFERRED_SIZE, PREFERRED_SIZE, Image.SCALE_REPLICATE);
        }
        return new ImageIcon(image);
    }
}
